@@ -105,12 +105,15 @@ public:
 	const char *chkEndinput(Line *line, ScriptImage *img);
 	const char *chkReconnect(Line *line, ScriptImage *img);
 	const char *chkRecall(Line *line, ScriptImage *img);
+	const char *chkRing(Line *line, ScriptImage *img);
+	const char *chkFeature(Line *line, ScriptImage *img);
 };
 
 class Methods : public BayonneSession
 {
 public:
 	bool scrKey(void);
+	bool scrRing(void);
 	bool scrRelease(void);
 	bool scrRecall(void);
 	bool scrConnect(void);
@@ -122,6 +125,7 @@ public:
 	bool scrEndform(void);
 	bool scrEndinput(void);
 	bool scrReconnect(void);
+	bool scrFeature(void);
 };
 
 } // namespace
