@@ -48,6 +48,7 @@ unsigned Bayonne::idle_count = 0;
 unsigned Bayonne::idle_limit = 0;
 bool Bayonne::shutdown_flag = false;
 time_t Bayonne::start_time = 0;
+time_t Bayonne::reload_time = 0;
 AtomicCounter Bayonne::libexec_count = 0;
 unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
@@ -213,45 +214,6 @@ Bayonne::Ring *Bayonne::Ring::attach(BayonneDriver *d, const char *id, Ring *lis
 	return r;
 };
 
-Bayonne::Call::Call(BayonneSession *dest, const char *from)
-{
-	time_t buf;
-	const char *dn = dest->getSymbol("session.dialed");
-	if(!dn)
-		dn = "unknown";
-
-	strcpy(call_id, dest->var_sid);
-	setString(call_from, sizeof(call_from), from);
-	setString(call_to, sizeof(call_to), dn);
-	call_connect = 0;
-	call_encoding = dest->audioEncoding();
-	refcount = 1;
-	call_type = dest->type;
-	call_start = time(&buf);
-}
-
-void Bayonne::Call::detach(const char *reason)
-{
-	if(reason && !reason[0])
-		setString(call_reason, sizeof(call_reason), reason);
-
-	--refcount;
-	if(!refcount)
-		BayonneBinder::reportCall(this);
-}
-
-void Bayonne::Call::attach(void)
-{
-	++refcount;
-}
-
-void Bayonne::Call::start(void)
-{
-	time_t buf;
-	if(!call_connect)
-		call_connect = time(&buf);
-}
-
 Bayonne::RPCNode::RPCNode(const char *id, RPCDefine *table)
 {
 	prefix = id;
@@ -928,6 +890,7 @@ ScriptCompiler *Bayonne::reload(void)
 	ScriptBinder::rebuild(img);
 	BayonneDriver::reload();
 	img->commit();
+	time(&reload_time);
 	reloading.unlock();
 	if(compile_count)
 		image_loaded = true;
@@ -1092,10 +1055,14 @@ BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const
 
 	setString(buffer, sizeof(buffer), dial);
 	sp = strchr(buffer, ':');
+	if(!sp)
+		sp = strchr(buffer, '/');
 	if(!sp)
 	{
 		setString(buffer, sizeof(buffer), name);
 		sp = strchr(buffer, ':');
+		if(!sp)
+			sp = strchr(buffer, '/');
 	}
 	
 	if(!sp)
@@ -1118,6 +1085,8 @@ BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const
 
 	if(strchr(dial, ':'))
 		dial = strchr(dial, ':') + 1;
+	else if(strchr(dial, '/'))
+		dial = strchr(dial, '/') + 1;
 	cp = d->getLast("type");
 	if(cp && !stricmp(cp, "proto"))
 		goto protocol;
