@@ -116,6 +116,7 @@ public:
 	typedef uint16_t timeslot_t;
 	typedef	int32_t	rpcint_t;
 #endif
+	typedef	rpcint_t rpcbool_t;
 
 protected:
 	static BayonneSession **timeslots;
@@ -132,8 +133,9 @@ protected:
 	static unsigned idle_count;
 	static unsigned idle_limit;
 	static bool shutdown_flag;
-	static char sla[];
+	static char sla[64];
 	static time_t start_time;
+	static time_t reload_time;
 
 public:
 	static timeout_t step_timer;
@@ -238,6 +240,7 @@ public:
 		STATE_IRESET,
 		STATE_FINAL,
 
+		STATE_SUSPEND = STATE_DOWN,
 		STATE_STANDBY = STATE_DOWN,
 		STATE_LIBEXEC = STATE_EXEC,
 		STATE_RINGING = STATE_RING,
@@ -501,6 +504,11 @@ public:
 		DROP_RECALL,
 		DROP_REFER,
 
+		// aliasing
+
+		ENTER_RESUME = MAKE_UP,
+		ENTER_SUSPEND = MAKE_DOWN, 
+
 		// master control events
 
 		SYSTEM_DOWN = 900,	
@@ -523,15 +531,6 @@ public:
 		RESULT_OFFLINE = 255
 	}	result_t;
 
-	typedef	enum
-	{
-		RPC_AUTH_INVALID = 0,
-		RPC_AUTH_NONE,
-		RPC_AUTH_REGISTRY,
-		RPC_AUTH_SYSTEM,
-		RPC_AUTH_ANY
-	}	rpcauth_t;
-
 	typedef	struct
 	{
 		Line line;
@@ -674,27 +673,6 @@ public:
 		static void start(Ring *list, BayonneSession *s);
 	};
 
-	/**
- 	 * This is an internal call class.
-	 */
-	class __EXPORT Call : public Audio
-	{
-	private:
-		volatile unsigned refcount;
-
-	public:
-		volatile time_t call_start, call_connect;
-		char call_from[65], call_to[65], call_reason[16];
-		char call_code[16], call_id[16];
-		calltype_t call_type;
-		const char *call_encoding;
-
-		Call(BayonneSession *target, const char *from);
-		void detach(const char *reason = NULL);
-		void attach(void);
-		void start(void);
-	};
-
 	/**
 	 * This is a class used for collecting statistics for call 
 	 * traffic measurement, such as might be used by MRTG.
@@ -744,7 +722,7 @@ public:
 		const char *prefix;
 
 	public:
-		inline RPCNode *getFirst(void)
+		static inline RPCNode *getFirst(void)
 			{return first;};
 
 		inline RPCNode *getNext(void)
@@ -1658,6 +1636,16 @@ protected:
 	void relistIdle(void);
 
 public:
+	/**
+	 * Determine if user id and secret is authorized for this
+	 * driver subsystem (registry).
+	 *
+	 * @param userid to check
+	 * @param secret to check
+	 * @return true if authorized
+	 */
+	virtual bool isAuthorized(const char *userid, const char *secret);
+
 	Traffic call_attempts, call_complete;
 	volatile unsigned short active_calls;
 
@@ -1699,6 +1687,15 @@ public:
 	 */
 	static inline BayonneDriver *getPrimary(void)
 		{return firstDriver;}
+
+	/**
+	 * Authorize a user and return associated driver.
+	 *
+	 * @param userid to authorize.
+	 * @param secret to use.
+	 * @return driver authorized under or NULL.
+	 */
+	static BayonneDriver *authorize(const char *userid, const char *secret);
 	
 	/**
 	 * Get next driver...
@@ -1706,6 +1703,8 @@ public:
 	inline BayonneDriver *getNext(void)
 		{return nextDriver;};
 
+	static inline BayonneDriver *getRoot(void)
+		{return firstDriver;};
 
 	/**
 	 * Return primary protocol driver...
@@ -1720,6 +1719,25 @@ public:
 	 */
 	BayonneSession *getIdle(void);
 
+	/**
+	 * Suspend a driver.
+	 *
+	 * @return true if successful.
+	 */
+	virtual bool suspend(void);
+
+	/**
+	 * Resume a driver.
+	 *
+	 * @return true if successful.
+	 */
+	virtual bool resume(void);
+
+	/**
+	 * Re-register.
+	 */
+	virtual void reregister(void);
+
 	/**
 	 * Process driver protocol specific proxy registration requests.
 	 *
@@ -2059,8 +2077,10 @@ public:
          * @return number of records filled.
          * @param data array to fill.
          * @param number of entries available.
+	 * @param optional id to match.
+	 * @param optional flag if only extensions.
          */
-        virtual unsigned getRegistration(regauth_t *data, unsigned count);
+        virtual unsigned getRegistration(regauth_t *data, unsigned count, const char *id = NULL);
 };	
 
 /**
@@ -2168,6 +2188,27 @@ public:
 	 */
 	inline unsigned getAvail(void)
 		{return count - used;}
+
+	/**
+	 * Suspend a span.
+	 *
+	 * @return true if successful.
+	 */
+	virtual bool suspend(void);
+
+	/**
+	 * Resume a suspended span.
+	 *
+	 * @return true if successful.
+	 */
+	virtual bool resume(void);
+
+	/**
+	 * Reset a span.
+	 *
+	 * @return true if successful.
+	 */
+	virtual bool reset(void);
 };
 
 /**
@@ -2179,13 +2220,12 @@ public:
 class __EXPORT BayonneBinder : public ScriptBinder, public Bayonne
 {
 private:
+	friend class __EXPORT BayonneSession;
 	static BayonneBinder *binder;
 
 protected:
 	virtual const char *submit(const char **data);
 
-	virtual void report(Call *call);
-
 	virtual ScriptCompiler *compiler(void);
 
 	BayonneSession *session(ScriptInterp *interp);
@@ -2196,9 +2236,11 @@ protected:
 
 	BayonneBinder(const char *id);
 
-public:
-	static void reportCall(Call *call);
+	virtual void makeCall(BayonneSession *child);
 
+	virtual void dropCall(BayonneSession *child);
+
+public:
 	static const char *submitRequest(const char **data);
 
 	static ScriptCompiler *getCompiler(void);
@@ -2218,7 +2260,6 @@ private:
 	friend class __EXPORT BayonneTranslator;
 	friend class __EXPORT BayonneDriver;
 	friend class __EXPORT Bayonne;
-	friend class __EXPORT Bayonne::Call;
 
 	BayonneSession() {};
 
@@ -2231,7 +2272,6 @@ protected:
 	static Mutex globalLock;	
 
 	std::ostream *logevents, *logtrace;
-	Call *call;
 	Ring *ring;
 	BayonneDriver *driver;
 	BayonneMsgport *msgport;
@@ -2259,6 +2299,21 @@ protected:
 	 */
 	bool requiresDTMF(void);
 
+	/**
+	 * Enter a co-joined call session; used to notify other
+	 * services.  Always performed by child node.
+	 */
+	void enterCall(void);
+
+	/**
+	 * Exit a co-joined call session; used to notify other
+	 * services.  May happen when a child node exits, drops
+	 * a recall, or is dropped by a parent.
+	 *
+	 * @param reason call is terminated.
+	 */
+	void exitCall(const char *reason);
+
 	/**
 	 * Enable dtmf detection for this channel.
 	 *
@@ -2365,17 +2420,6 @@ protected:
 	bool stateReconnect(Event *event);
 	bool stateCalling(Event *event);
 
-	/**
-	 * Set call reference pointer.  If previous call is set, then
-	 * it is detached.  Use NULL to clear current call if present.
-	 */
-	void setCall(Call *call, const char *reason = NULL);
-
-	/**
-	 * Make a new call, typically in a child process...
-	 */
-	void makeCall(const char *from);
-
 	/**
 	 * Direct method to post an event to a channel.
 	 *
@@ -2589,6 +2633,7 @@ protected:
 	const char *voicelib;
 	char *dtmf_digits;		// dtmf sym space;
 	unsigned digit_count, ring_count;
+	time_t time_joined;
 
 	State state;
 
@@ -2625,6 +2670,12 @@ public:
 	 */
 	void detach(void);
 
+	/**
+	 * Return time this call is joined or 0 if not child node.
+	 */
+	inline time_t getJoined(void)
+		{return time_joined;};
+
 	/**
 	 * Return driver associated with this session.
 	 *
@@ -2808,6 +2859,13 @@ public:
 	 */
 	bool isJoined(void);
 
+	/**
+	 * Return state of association with parent in call.
+	 *
+	 * @return true if currently associated.
+	 */
+	bool isAssociated(void);
+
 	inline bool isHolding(void)
 		{return holding;};
 
@@ -2942,10 +3000,16 @@ public:
 		size_t bufused;
 		const char *agent_id;
 		const char *protocol;
-		const char *authorization;	// user:secret
-		rpcauth_t authorized;	// authorized by web server...
+		bool authorized;		// transport authorized
+		const char *userid;		// null if anonymous
+		BayonneDriver *driver;		// authorizing driver
 	}	transport;
 
+	struct {
+		unsigned code;
+		const char *string;
+	}	result;
+
         struct {
 		const char *prefix;	// xmlrpc has prefix, soap NULL
                 const char *method;
@@ -2957,13 +3021,16 @@ public:
 	inline unsigned getCount(void)
 		{return params.argc;};
 
-	const char *getIndexed(unsigned short param, unsigned short offset);
+	const char *getIndexed(unsigned short param, unsigned short offset = 0);
 	const char *getNamed(unsigned short param, const char *member);
 	const char *getMapped(const char *map, const char *member);
 
 	bool buildResponse(const char *fmt, ...);
 	void sendSuccess(void);
 	void sendFault(int code, const char *string);
+	
+	inline void transportFault(unsigned code, const char *string)
+		{result.code = code; result.string = string;};
 
 	bool invokeXMLRPC(void);
 };	
@@ -2979,6 +3046,8 @@ public:
 class __EXPORT BayonneService : public Thread                
 {          
 private:            
+	friend class __EXPORT BayonneSession;
+
         static BayonneService *first;
 	static BayonneService *last;
         BayonneService *next;
@@ -3001,24 +3070,26 @@ protected:
 	/**
 	 * Used at end of call.
 	 */
-	virtual void detachCall(BayonneSession *s);
+	virtual void detachSession(BayonneSession *s);
 
 	/**
 	 * Used at running state.
 	 */
-	virtual void activeCall(BayonneSession *s);
+	virtual void attachSession(BayonneSession *s);
 
 	/**
-	 * Used to notify for an extension ringing.
+	 * Used to notify when call is joined.
 	 */
-	virtual void notifyCall(BayonneSession *s);
+	virtual void enteringCall(BayonneSession *child);
+
+	/**
+	 * Used to notify when exiting join.
+	 */
+	virtual void exitingCall(BayonneSession *child);
 
 public:
 	static void start(void);
 	static void stop(void); 
-	static void detach(BayonneSession *s);
-	static void active(BayonneSession *s);
-	static void notify(BayonneSession *s);
 };
 
 } // namespace
