@@ -85,11 +85,30 @@ BayonneDriver::~BayonneDriver()
 	}
 }
 
+bool BayonneDriver::suspend(void)
+{
+	return false;
+}
+
+bool BayonneDriver::resume(void)
+{
+	return false;
+}
+
+void BayonneDriver::reregister(void)
+{
+}
+
 bool BayonneDriver::isExternal(const char *ext)
 {
 	return false;
 }
 
+bool BayonneDriver::isAuthorized(const char *userid, const char *secret)
+{
+	return false;
+}
+
 bool BayonneDriver::isRegistered(const char *ext)
 {
 	return isExternal(ext);
@@ -111,7 +130,7 @@ void BayonneDriver::relistIdle(void)
 	firstIdle = lastIdle = NULL;
 }
 
-unsigned BayonneDriver::getRegistration(regauth_t *data, unsigned count)
+unsigned BayonneDriver::getRegistration(regauth_t *data, unsigned count, const char *id)
 {
         return 0;
 }
@@ -390,6 +409,26 @@ void BayonneDriver::stopDriver(void)
 	running = false;
 }
 
+BayonneDriver *BayonneDriver::authorize(const char *userid, const char *secret)
+{
+	BayonneDriver *driver = firstDriver;
+
+	if(!userid)
+		userid = "anonymous";
+
+	if(!secret)
+		secret = "";
+
+	while(driver)
+	{
+		if(driver->isAuthorized(userid, secret))
+			break;
+
+		driver = driver->nextDriver;
+	}
+	return driver;
+}
+
 BayonneDriver *BayonneDriver::get(const char *id)
 {
 	BayonneDriver *driver = firstDriver;
