@@ -158,6 +158,61 @@ void Session::htmlHeader(const char *title, bool refresh)
 }
 
 void Session::htmlCalls(void)
+{
+	BayonneSession *s;
+	timeslot_t index = 0;
+	char status[16];
+	time_t now;
+	long diff;
+	const char *from, *to;
+
+	htmlHeader("Bayonne Calls", true);
+	sendText("<TABLE border=\"1\" summary=\"Active Calls\">\r\n");
+	sendText("<CAPTION><EM>Active Calls</EM></CAPTION>\r\n");
+	sendText("<TR><TH>Parent<TH>Child<TH>Status<TH>From<TH>To\r\n");
+
+	time(&now);
+	while(index < ts_used)
+	{
+		s = getSession(index++);
+		if(!s)
+			continue;
+
+		s->enter();
+		if(!s->isAssociated())
+		{
+			s->leave();
+			continue;
+		}
+
+		if(!s->getJoined())
+			setString(status, sizeof(status), "ringing");
+		else
+		{
+			diff = (long)(now - s->getJoined());
+			snprintf(status, sizeof(status), "%02ld:%02ld:%02ld",
+				diff / 3600l, (diff / 60) % 60, diff % 60);
+		}
+		from = s->getSymbol("session.associated");
+		if(!from || !*from)
+			from = s->getSymbol("session.caller");
+		to = s->getSymbol("session.identity");
+		if(!to)
+			to = s->getSymbol("session.dialed");
+		snprintf(buffer, sizeof(buffer),
+			"<TR><TD>%s<TD>%s<TD>%s<TD>%s<TD>%s\r\n",
+			s->getExternal("session.pid"),
+			s->getExternal("session.id"),
+			status, from, to);
+
+		sendText(buffer);
+		s->leave();
+	}
+	sendText("</TABLE>\r\n");
+	htmlFooter();
+}
+
+void Session::htmlSessions(void)
 {
 	BayonneSession *s;
 	timeslot_t index = 0;
@@ -196,6 +251,7 @@ void Session::htmlCalls(void)
 	htmlFooter();
 }
 
+
 void Session::htmlControl(void)
 {
 	const char *cmd = NULL;
