@@ -33,6 +33,9 @@ using namespace std;
 #define	XML_ARGUMENT_MISSING	601
 #define	XML_COMMAND_FAILED	600
 
+#define	MAX_XML_REQUEST		2048
+#define	MAX_XML_REPLY		16384
+
 class Service : public BayonneService, public BayonneZeroconf, public Keydata
 {
 private:
@@ -42,26 +45,28 @@ private:
 public:
 	static bool active;
 	static Service webservice;
+	static Keydata admin, rpc;
 	Service();
 };
 
 class Session : public BayonneRPC, public Socket, public Thread
 {
 protected:
-	char buffer[1024];
+	char buffer[MAX_XML_REQUEST];
 	char request[128];
 	char auth[128];
 	const char *req_command;
 	const char *req_path;
 	char *req_query;
 	char *req_auth;
+	char *req_agent;
 	regauth_t regs[1024];
 
 	void syncExit(void);
 	void run(void);
 	void sendText(const char *text);
-	void sendAuth(const char *text, const char *ctype = NULL);
-	void sendError(const char *text, const char *ctype = NULL);
+	void sendAuth(const char *text, const char *ctype = NULL, size_t size = 0);
+	void sendError(const char *text, const char *ctype = NULL, size_t size = 0);
 	void sendHeader(const char *ctype = "text/html", unsigned long clen = 0);
 	void rpcFault(int code, const char *text);
 	void rpcReply(const char *string = NULL);	
@@ -71,6 +76,7 @@ protected:
 	void htmlHeader(const char *title, bool refresh);
 	void htmlFooter(void);
 	void htmlStatus(void);
+	void htmlSessions(void);
 	void htmlCalls(void);
 	void htmlControl(void);
 
