@@ -23,11 +23,13 @@ using namespace std;
 
 Service Service::webservice;
 bool Service::active = false;
+Keydata Service::admin("/bayonne/web/admin");
+Keydata Service::rpc("/bayonne/web/rpc");
 
 Service::Service() :
 BayonneService(0, 0), 
 BayonneZeroconf("_http._tcp"),
-Keydata("/bayonne/module/webservice")
+Keydata("/bayonne/web/service")
 {
 	const char *cp;
 
@@ -41,15 +43,20 @@ Keydata("/bayonne/module/webservice")
 	{"refresh", "10"},
 	{"realm", "bayonne"},
 	{"datafiles", WEBSERVER_FILES}, 
+	{"logfiles", LOG_FILES},
 	{"zeroconf", "yes"},
 	{NULL, NULL}};
 
 	if(Bayonne::getUserdata())
+	{
 	        load("~bayonne/webservice");
+		admin.load("~bayonne/webadmin");
+		rpc.load("~bayonne/webrpc");
+	}
 
 	load(defkeys);
 #ifdef	WIN32
-	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\module.ini", "webservice");
+	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\web.ini", "service");
 #endif
 	cp = getLast("zeroconf");
 	switch(*cp)
