@@ -302,16 +302,20 @@ void liveConfig(void)
 #define	EVENTS	"%s/%s.evt"
 #define	ERRORS	"%s/%s.err"
 #define	OUTPUT	"%s/%s.out"
-#define	CALLER	"%s/%s.cdr"
+#define	CALLER	"%s/%s.log"
+#define	CALLS   "%s/%s.cdr"
 #define	STATS	"%s/%s.sta"
 #else
 #define	EVENTS	"%s/%s.events"
 #define	ERRORS	"%s/%s.errors"
 #define	OUTPUT	"%s/%s.output"
-#define	CALLER	"%s/%s.calls"
+#define	CALLER	"%s/%s.sessions"
+#define CALLS	"%s/%s.calls"
 #define	STATS	"%s/%s.stats"
 #endif
 
+	runtime.setValue("node", keyserver.getLast("node"));
+
 	snprintf(path, sizeof(path), ERRORS,
 		keypaths.getLast("logfiles"), keyserver.getLast("node"));
 	runtime.setValue("errlog", path);
@@ -328,6 +332,10 @@ void liveConfig(void)
                 keypaths.getLast("logfiles"), keyserver.getLast("node"));
         runtime.setValue("calls", path);
 
+        snprintf(path, sizeof(path), CALLS, 
+		keypaths.getLast("logfiles"), keyserver.getLast("node"));
+        runtime.setValue("cdr", path);
+
         snprintf(path, sizeof(path), STATS,
                 keypaths.getLast("logfiles"), keyserver.getLast("node"));
         runtime.setValue("stats", path);
