@@ -20,6 +20,19 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrTrap(void)
+{
+	const char *id = getKeyword("id");
+	const char *text = getKeyword("text");
+
+	if(!id)
+		id = "6";
+
+	Bayonne::snmptrap(atoi(id), text);
+	advance();
+	return true;
+}
+
 bool Methods::scrSay(void)
 {
 	char buf[256];
