@@ -140,6 +140,10 @@ ScriptRuntime()
 			(Check)&Checks::chkPathname},
 		{"say", false, (Method)&Methods::scrSay,
 			(Check)&Checks::chkSay},
+		{"trap", false, (Method)&Methods::scrTrap,
+			(Check)&Checks::chkTrap},
+                {"snmptrap", false, (Method)&Methods::scrTrap,
+                        (Check)&Checks::chkTrap},
         	{NULL, false, NULL, NULL}};
 
         trap("timeout", false);
