@@ -496,7 +496,20 @@ int main(int argc, char **argv)
 		checking();
 
 	Process::setScheduler(keyengine.getLast("scheduler"));
-        Process::setPriority(atoi(keyengine.getLast("priority")));   
+        Process::setPriority(atoi(keyengine.getLast("priority")));
+	cp = keyserver.getLast("community");
+	if(cp)
+		Bayonne::trap_community = cp;
+	cp = keyserver.getLast("traps");
+	if(!cp)
+		cp = keyserver.getLast("trap4");
+	if(cp)
+		Bayonne::addTrap4(cp);
+#ifdef	CCXX_IPV6
+	cp = keyserver.getLast("trap6");
+	if(cp)
+		Bayonne::addTrap6(cp);
+#endif   
 #ifndef WIN32
         if(!getuid())
         {
